/*
 * mac.h
 *
 *  Created on: 13.11.2017
 *      Author: seidl
 */

#ifndef MAC_UIP_FUNCTIONS_H_
#define MAC_UIP_FUNCTIONS_H_

#include "hw_platform.h"
#include "cortex_nvic.h"
#include "drivers/CoreGPIO/core_gpio.h"
#include "drivers/CoreUARTapb/core_uart_apb.h"
#include "drivers/CoreI2C/core_i2c.h"
#include "drivers/CoreTimer/core_timer.h"
#include "hal.h"
#include "string.h"
#include "stdio.h"
#include "inttypes.h"

#include "./CMSIS/cortexm1_cfg.h"
#include "./CMSIS/system_cortexm1_cfg.h"

#include "uip.h"
#include "uip_arp.h"

#define BUF ((struct uip_eth_hdr *)&uip_buf[0])

#define TIMER0_BASE_ADDRESS    	    0x00045000UL
#define MAC10GB_BASE_ADDRESS    	0x00043000UL
#define MAC10GBFIFO_BASE_ADDRESS   	0x00044000UL

// 10GMAC Registers
#define MAC_TX_CONFIG_CONFIG_REG_OFFSET     0x28Cu
#define MAC_TX_CONFIG_SYSTEM1_REG_OFFSET    0x290u
#define MAC_RX_CONFIG_STATIC_REG_OFFSET     0x2C0u
#define MAC_RX_CONFIG_CONFIG_REG_OFFSET     0x2CCu

#define MAC_TX_STATUS_PKTOK_COUNTER_REG_OFFSET     		0x330u
#define MAC_TX_STATUS_PKTPAD_COUNTER_REG_OFFSET    		0x32Cu
#define MAC_TX_STATUS_PKTVLAN_COUNTER_REG_OFFSET    	0x328u
#define MAC_TX_STATUS_PKTCTRL_COUNTER_REG_OFFSET    	0x324u
#define MAC_TX_STATUS_PAUSE_COUNTER_REG_OFFSET    		0x320u
#define MAC_TX_STATUS_MULTICAST_COUNTER_REG_OFFSET    	0x31Cu
#define MAC_TX_STATUS_BROADCAST_COUNTER_REG_OFFSET    	0x318u
#define MAC_TX_STATUS_ERR_COUNTER_REG_OFFSET    		0x314u
#define MAC_TX_STATUS_ERRFRM_COUNTER_REG_OFFSET    		0x310u
#define MAC_TX_STATUS_ERRFCS_COUNTER_REG_OFFSET    		0x30Cu
#define MAC_TX_STATUS_ERRLENSHORT_COUNTER_REG_OFFSET    0x308u
#define MAC_TX_STATUS_ERRLENCHECK_COUNTER_REG_OFFSET    0x304u
#define MAC_TX_STATUS_ERRLENLONG_COUNTER_REG_OFFSET		0x300u

#define MAC_RX_STATUS_PKTOK_COUNTER_REG_OFFSET     		0x370u
#define MAC_RX_STATUS_PKTPAD_COUNTER_REG_OFFSET    		0x36Cu
#define MAC_RX_STATUS_PKTVLAN_COUNTER_REG_OFFSET    	0x368u
#define MAC_RX_STATUS_PKTCTRL_COUNTER_REG_OFFSET    	0x364u
#define MAC_RX_STATUS_PAUSE_COUNTER_REG_OFFSET    		0x360u
#define MAC_RX_STATUS_MULTICAST_COUNTER_REG_OFFSET    	0x35Cu
#define MAC_RX_STATUS_BROADCAST_COUNTER_REG_OFFSET    	0x358u
#define MAC_RX_STATUS_ERR_COUNTER_REG_OFFSET    		0x354u
#define MAC_RX_STATUS_ERRFRM_COUNTER_REG_OFFSET    		0x350u
#define MAC_RX_STATUS_ERRFCS_COUNTER_REG_OFFSET    		0x34Cu
#define MAC_RX_STATUS_ERRLENSHORT_COUNTER_REG_OFFSET    0x348u
#define MAC_RX_STATUS_ERRLENCHECK_COUNTER_REG_OFFSET    0x344u
#define MAC_RX_STATUS_ERRLENLONG_COUNTER_REG_OFFSET		0x340u

void configure_10GMAC(void);
void init_eth_regs(void);
uint32_t MAC_rx_packet();
void MAC_tx_packet(uint32_t len);
void check_tx_length(uint16_t *length);


uip_ipaddr_t ipaddr;
struct uip_eth_addr macaddr;



#endif /* MAC_UIP_FUNCTIONS_H_ */
